@@ -9,3 +9,8 @@
 
 def get_number_plus_one(number: int):
     return number + 1
+
+
+def get_number_plus_two(number: int):
+    return number + 2
+
